import Image from "next/image";
import { Suspense } from "react";

import { AboutLoadingSkeleton, ShopLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import Ads from "@/components/sections/home/ads";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import LocomotiveScrollWrapper from "@/components/ui/locomotive-scroll-wrapper";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";
import { getLocale, getTranslations } from "next-intl/server";


export default async function ProductDetailsPage({
	params,
}: {
	params: Promise<{ slug: string[] }>;
}) {
	const { slug } = await params;
	const locale = await getLocale() as Locale;
	const t = await getTranslations();

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);


	const _data = queryClient.getQueryData<any>(["basicInfo"]);

	const _blog = _data?.data?.company_news?.find((val: any) => val.text?.[locale]?.trim().replace(/\s+/g, "-") == decodeURIComponent(slug?.[0]));

	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<LocomotiveScrollWrapper>
				<main className="block">
					<Header />
					<Suspense fallback={<AboutLoadingSkeleton locale={locale} />}>
						<PageBreadcrump
							locale={locale}
							subtitle={{
								en: "Company News",
								ar: "اخبار الشركة",
							}}
							title={{
								en: _blog?.text?.en,
								ar: _blog?.text?.ar,
							}}
							breadcrumbItems={breadcrumbItems}
							backgroundUrl="/project.png"
						/>
						<div className="px-2 mb-36 sm:px-2 md:px-4 lg:px-4 xl:px-28">
							<Suspense fallback={<ShopLoadingSkeleton locale={locale} />}>
								<Image src={ImageBaseUrl + _blog?.image} alt={_blog?.text?.[locale]} width={600} height={400}
									className="rounded-lg mt-8 mx-auto" />
							</Suspense>
							<div className="flex flex-row justify-between mt-4">
								<div className="text-md text-custom-primary-accent">
									{t("date")}: {_blog?.writing_date}
								</div>
								<div className="text-md text-custom-primary-accent">
									{t("author")}: {_blog?.author_name?.[locale]}
								</div>
							</div>

							<hr className="my-4" />

							<div className="text-xl py-6 text-center text-gray-500">
								{_blog?.description?.[locale]}
							</div>

						</div>
						<Ads />
					</Suspense>
					<Footer />
				</main>
			</LocomotiveScrollWrapper>
		</HydrationBoundary>
	);
}
